Welcome to The Arcade Library!
==============================

Arcade is an easy-to-learn Python library for creating 2D video games.
It is ideal for beginning programmers, or programmers who want to create
2D games without learning a complex framework.

Arcade is built on top of Pyglet and OpenGL.

.. image:: https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat)
    :target: http://makeapullrequest.com
    :alt: Pull Requests Welcome

.. image:: https://img.shields.io/badge/first--timers--only-friendly-blue.svg
    :alt: first-timers-only Friendly
    :target: http://www.firsttimersonly.com/

.. image:: https://img.shields.io/pypi/dm/arcade
    :alt: PyPI - Downloads

.. image:: https://img.shields.io/github/commit-activity/m/pythonarcade/arcade
    :alt: GitHub commit activity

.. image:: https://img.shields.io/pypi/l/arcade
    :alt: PyPI - License

Documentation
-------------

* For full documentation see https://api.arcade.academy
* For installation: https://api.arcade.academy/en/latest/install/index.html
* For example code that uses the Arcade library see: https://api.arcade.academy/en/latest/examples/index.html
* For API documentation see: https://api.arcade.academy/en/latest/quick_index.html
* Learn Arcade AND how to program: https://learn.arcade.academy
* Release notes: https://api.arcade.academy/en/latest/development/release_notes.html

Games Using Arcade
------------------

See: https://api.arcade.academy/en/latest/sample_games.html

Contact the Maintainer
----------------------

paul@cravenfamily.com